==> vradi-swing-0.0.1-sources.jar: com/jurismarches/vradi/ui/editors/UrlEditor.java <==
package com.jurismarches.vradi.ui.editors;

import com.jurismarches.vradi.ui.editors.*;
import java.awt.*;
import java.awt.event.*;
import java.beans.*;
import java.io.*;
import java.lang.*;
import java.util.*;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.event.*;
import jaxx.runtime.swing.JAXXButtonGroup;
import jaxx.runtime.swing.HBox;
import jaxx.runtime.swing.VBox;
import jaxx.runtime.swing.Table;
import jaxx.runtime.Util;
import jaxx.runtime.SwingUtil;
import static org.nuiton.i18n.I18n._;
import static jaxx.runtime.Util.createImageIcon;
import com.jurismarches.vradi.entities.*;
import com.jurismarches.vradi.services.dto.*;
import com.jurismarches.vradi.VradiContext;
import jaxx.runtime.swing.editor.*;
import jaxx.runtime.swing.EntityComboBox;
import static jaxx.runtime.validator.BeanValidatorUtil.convert;
import static jaxx.runtime.SwingUtil.getStringValue;
import static org.nuiton.i18n.I18n.n_;
import com.jurismarches.vradi.ui.OfferEditHandler;
import jaxx.runtime.DataBindingListener;

public class UrlEditor extends com.jurismarches.vradi.ui.editors.VradiEditor {
    private static String $jaxxObjectDescriptor = "H4sIAAAAAAAAAI1SPW8TQRR8PmwHx5gkWImCCFKAdJHWUBtBIoMFkQEJBxThhrVvFa91H5vdd8nRIH4CPwF6GiQ6KkRBTUGD+AsIUdAi3t45PhsOgYuztG9mdnbmvfoKJaPhwojHMdNRgNIXbGd7b+9efyQGeEOYgZYKQw3pr+CA04OqOzk3CJd6HUtvjOmNVuirMBDBFLvZgXmDTzxhhkIgwvlZxsCYRncybsYq0seqE1N5qi++f3Oeu89eOgCxIndFesr6v1jZS4odcKSLcIZuOuQNjwf7ZEPLYJ/81uxZy+PG3OW+OICnMNeBsuKaxBAu/v+TE42EHyuE2sZDzV1505WEuYywOQh9Noq0ND7Xg6Ew7NDOWSSZSDCGPdBeClcq0SkjFF2OHGHRemTWN0t9Z4haym6FASaGV2diMUcEZru874mMUt3Y2RUxbmvBryAsW+14jJwMLHRBUcznZvSoQJYVmCVc6EFJR3RMBnp/dn6fRmnbq7+1bQWT6c+V+qe3X960jysu0N3LudCpDaXolQ6V0Cjt1QtpvxFKr3GHq2YPKkZ4tN7J+q7lGOuOx2SO7ltKYrZ0doubIUmU5j6/e7/y+OMJcNow74XcbXOLvw0VHGpKIfTcWF3fShydOjpJ30XrjZpDShLh9FXb4HpfBi7ley2mCNZyIpj46Fc+/Kh3X29Nx3D2r/AsitIjKMvAk4FIdn28xrm7XVVGRG6YrWveAhfsf10p9QtOFy8FOQQAAA==";
    private static final long serialVersionUID = 1L;
    protected java.lang.String data;
    private javax.swing.JTextArea $JTextArea1;
    private UrlEditor $VradiEditor0 = this;
    private boolean allComponentsCreated;
    private boolean contextInitialized = true;
    private PropertyChangeListener $DataSource2 = new DataBindingListener(this, "$JTextArea1.text");

    /* begin raw body code */    
    protected OfferEditHandler getHandler() {
        return getContextValue(OfferEditHandler.class);
    }
    
    protected VradiContext getVradiContext() {
        return VradiContext.get();
    }
    
    void $afterCompleteSetup() {
    }
    /* end raw body code */
    /*---------------------------------------------------------------------------------*/
    /*-- Statics methods --------------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public static jaxx.runtime.JAXXObjectDescriptor $getJAXXObjectDescriptor() {
        return jaxx.runtime.Util.decodeCompressedJAXXObjectDescriptor($jaxxObjectDescriptor);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- Constructors -----------------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public UrlEditor() {
        super();
        $initialize();
    }

    public UrlEditor(jaxx.runtime.JAXXContext parentContext) {
        super(parentContext);
        $initialize();
    }

    /*---------------------------------------------------------------------------------*/
    /*-- JAXXObject implementation ----------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    @Override
    public void applyDataBinding(String $binding) {
        if ("$JTextArea1.text".equals($binding)) {    
            addPropertyChangeListener("data", $DataSource2);
        } else {
            super.applyDataBinding($binding);
            return;
        }
        processDataBinding($binding);
    }

    @Override
    public void processDataBinding(String $dest, boolean $force) {
        if (!$force && $activeBindings.contains($dest)) { 
            return;
        }
        $activeBindings.add($dest);
        try {
            if ("$JTextArea1.text".equals($dest)) {
                jaxx.runtime.SwingUtil.setText($JTextArea1, getData());
            } else {
                super.processDataBinding($dest, true);
            }
        } finally {
            $activeBindings.remove($dest);
        }
    }

    @Override
    public void removeDataBinding(String $binding) {
        if ("$JTextArea1.text".equals($binding)) {    
            removePropertyChangeListener("data", $DataSource2);
        } else {
            super.removeDataBinding($binding);
        }
    }

    /*---------------------------------------------------------------------------------*/
    /*-- public acessor methods -------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public java.lang.String getData() {
        return data;
    }

    /*---------------------------------------------------------------------------------*/
    /*-- public mutator methods -------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public void setData(java.lang.String newValue) {
        java.lang.String oldValue = this.data;
        this.data = newValue;
        firePropertyChange("data", oldValue, newValue);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- protected acessors methods ---------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    protected javax.swing.JTextArea get$JTextArea1() {
        return $JTextArea1;
    }

    /*---------------------------------------------------------------------------------*/
    /*-- ui creation methods ----------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    private void $completeSetup() {
        allComponentsCreated = true;
        addChildrenToEditorContent();
        // init data bindings
        applyDataBinding("$JTextArea1.text");
        $afterCompleteSetup();
    }

    private void $initialize() {
        if (allComponentsCreated || !contextInitialized) {
            return;
        }
        $objectMap.put("$VradiEditor0", this);
        createData();
        // inline creation of $JTextArea1
        $objectMap.put("$JTextArea1", $JTextArea1 = new javax.swing.JTextArea());
        $JTextArea1.setName("$JTextArea1");
        $JTextArea1.setColumns(15);
        $JTextArea1.setLineWrap(true);
        $JTextArea1.setWrapStyleWord(true);
        // inline creation of $VradiEditor0
        removeDataBinding("$Table0.name");
        setName("$VradiEditor0");
        
        $completeSetup();
    }

    protected void addChildrenToEditorContent() {
        if (!allComponentsCreated) {
            return;
        }
        editorContent.add($JTextArea1, new GridBagConstraints(0, 0, 1, 1, 1.0, 0.0, 10, 2, new Insets(0, 0, 0, 0), 0, 0));
    }

    protected void createData() {
        $objectMap.put("data", data = null);
    }

    @Override
    protected void createEditorContent() {
        $objectMap.put("editorContent", editorContent = new jaxx.runtime.swing.Table());
        editorContent.setName("editorContent");
    }

}

==> vradi-swing-0.0.2-sources.jar: com/jurismarches/vradi/ui/editors/UrlEditor.java <==
package com.jurismarches.vradi.ui.editors;

import com.jurismarches.vradi.ui.editors.*;
import java.awt.*;
import java.awt.event.*;
import java.beans.*;
import java.io.*;
import java.lang.*;
import java.util.*;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.event.*;
import jaxx.runtime.swing.JAXXButtonGroup;
import jaxx.runtime.swing.HBox;
import jaxx.runtime.swing.VBox;
import jaxx.runtime.swing.Table;
import jaxx.runtime.Util;
import jaxx.runtime.SwingUtil;
import static org.nuiton.i18n.I18n._;
import static jaxx.runtime.Util.createImageIcon;
import com.jurismarches.vradi.entities.*;
import com.jurismarches.vradi.services.dto.*;
import com.jurismarches.vradi.VradiContext;
import jaxx.runtime.swing.editor.*;
import jaxx.runtime.swing.EntityComboBox;
import static jaxx.runtime.validator.BeanValidatorUtil.convert;
import static jaxx.runtime.SwingUtil.getStringValue;
import static org.nuiton.i18n.I18n.n_;
import com.jurismarches.vradi.ui.OfferEditHandler;
import jaxx.runtime.DataBindingListener;

public class UrlEditor extends com.jurismarches.vradi.ui.editors.VradiEditor {
    private static String $jaxxObjectDescriptor = "H4sIAAAAAAAAAI1SsW4TQRR8PmwHJ5gkWImCCFKAdEh79EaQyGBBZEDCAUVcw9q3itc632123yVHg/gEPgF6GiQ6KkRBTUGD+AWEKGgRb+8cnw2HwMVZ2p2ZNzvzXn2FitFwYciThOk4RDkSbGd7b+9ebyj6eEOYvpYKIw3Zr+SA48GCPzk3CJe8jqW7Y7rbikYqCkU4xW52YN7gk0CYgRCIcH6W0TfG7U6um4mK9bHqxFSR6ovv35zn/rOXDkCiyF2ZnrLxL1b+knIHHOkjnKFJh9wNeLhPNrQM98lv3Z61Am7MXT4SB/AU5jpQVVyTGMLF/39yqpHyE4VQ33youS9v+pIwVxAu96MRG8ZamhHX/YEw7NDes1gykWIMe6CDDK5UqlNFKPscOcKS9cisb5b5zhH1jN2KQkwNr83EYo4IzHZ5LxA5pZpREFasbDIG7eyKBLe14Ba1qCjhczNS1B3Lu8vDLXlQ0TEd02zvz7rv01VW9NpvRVvB9PbnauPT2y9v2sftlmj2SiF0ajkpdaUjJTRKO3oxqzZGGbh3uGp6UDMioM1ON3e9wFh3fE3maN5ymrCls1vcDEiiMvf53fvVxx9PgNOG+SDifptb/G2o4UBTClHgJ+r6Vuro1NFJ+i5Zb1QaUpIIp6/a8jZ6MvQp32sJRbBeEMHER6/24Uej+3prOoazf4XnUVQeQVWGgQxFuubjDS5c6wVlROxH+aYW7W7J/jeUUr8Am60k6zQEAAA=";
    private static final long serialVersionUID = 1L;
    protected java.lang.String data;
    protected javax.swing.JTextArea editor;
    private UrlEditor $VradiEditor0 = this;
    private boolean allComponentsCreated;
    private boolean contextInitialized = true;
    private PropertyChangeListener $DataSource1 = new DataBindingListener(this, "editor.text");

    /* begin raw body code */    
    protected OfferEditHandler getHandler() {
        return getContextValue(OfferEditHandler.class);
    }
    
    protected VradiContext getVradiContext() {
        return VradiContext.get();
    }
    
    void $afterCompleteSetup() {
    }
    /* end raw body code */
    /*---------------------------------------------------------------------------------*/
    /*-- Statics methods --------------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public static jaxx.runtime.JAXXObjectDescriptor $getJAXXObjectDescriptor() {
        return jaxx.runtime.Util.decodeCompressedJAXXObjectDescriptor($jaxxObjectDescriptor);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- Constructors -----------------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public UrlEditor() {
        super();
        $initialize();
    }

    public UrlEditor(jaxx.runtime.JAXXContext parentContext) {
        super(parentContext);
        $initialize();
    }

    /*---------------------------------------------------------------------------------*/
    /*-- JAXXObject implementation ----------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    @Override
    public void applyDataBinding(String $binding) {
        if ("editor.text".equals($binding)) {    
            addPropertyChangeListener("data", $DataSource1);
        } else {
            super.applyDataBinding($binding);
            return;
        }
        processDataBinding($binding);
    }

    @Override
    public void processDataBinding(String $dest, boolean $force) {
        if (!$force && $activeBindings.contains($dest)) { 
            return;
        }
        $activeBindings.add($dest);
        try {
            if ("editor.text".equals($dest)) {
                jaxx.runtime.SwingUtil.setText(editor, getData());
            } else {
                super.processDataBinding($dest, true);
            }
        } finally {
            $activeBindings.remove($dest);
        }
    }

    @Override
    public void removeDataBinding(String $binding) {
        if ("editor.text".equals($binding)) {    
            removePropertyChangeListener("data", $DataSource1);
        } else {
            super.removeDataBinding($binding);
        }
    }

    /*---------------------------------------------------------------------------------*/
    /*-- public acessor methods -------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public java.lang.String getData() {
        return data;
    }

    public javax.swing.JTextArea getEditor() {
        return editor;
    }

    /*---------------------------------------------------------------------------------*/
    /*-- public mutator methods -------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    public void setData(java.lang.String newValue) {
        java.lang.String oldValue = this.data;
        this.data = newValue;
        firePropertyChange("data", oldValue, newValue);
    }

    /*---------------------------------------------------------------------------------*/
    /*-- ui creation methods ----------------------------------------------------------*/
    /*---------------------------------------------------------------------------------*/

    private void $completeSetup() {
        allComponentsCreated = true;
        addChildrenToEditorContent();
        // init data bindings
        applyDataBinding("editor.text");
        $afterCompleteSetup();
    }

    private void $initialize() {
        if (allComponentsCreated || !contextInitialized) {
            return;
        }
        $objectMap.put("$VradiEditor0", this);
        createData();
        createEditor();
        // inline creation of $VradiEditor0
        removeDataBinding("$Table0.name");
        setName("$VradiEditor0");
        
        $completeSetup();
    }

    protected void addChildrenToEditorContent() {
        if (!allComponentsCreated) {
            return;
        }
        editorContent.add(editor, new GridBagConstraints(0, 0, 1, 1, 1.0, 0.0, 10, 2, new Insets(0, 0, 0, 0), 0, 0));
    }

    protected void createData() {
        $objectMap.put("data", data = null);
    }

    protected void createEditor() {
        $objectMap.put("editor", editor = new javax.swing.JTextArea());
        editor.setName("editor");
        editor.setColumns(15);
        editor.setLineWrap(true);
        editor.setWrapStyleWord(true);
    }

    @Override
    protected void createEditorContent() {
        $objectMap.put("editorContent", editorContent = new jaxx.runtime.swing.Table());
        editorContent.setName("editorContent");
    }

}
